==> react-molecule-dropdown-list-1.15.0.tgz: package/lib/index.js <==
import _extends from "@babel/runtime/helpers/esm/extends";
import _objectWithoutPropertiesLoose from "@babel/runtime/helpers/esm/objectWithoutPropertiesLoose";
import React, { useRef } from 'react';
import cx from 'classnames';
var BASE_CLASS = "sui-MoleculeDropdownList";
var CLASS_HIDDEN = "is-hidden";
var SIZES = {
  SMALL: 'small',
  MEDIUM: 'medium',
  LARGE: 'large'
};

var MoleculeDropdownList = function MoleculeDropdownList(_ref) {
  var _cx;

  var children = _ref.children,
      onSelect = _ref.onSelect,
      alwaysRender = _ref.alwaysRender,
      size = _ref.size,
      value = _ref.value,
      visible = _ref.visible,
      props = _objectWithoutPropertiesLoose(_ref, ["children", "onSelect", "alwaysRender", "size", "value", "visible"]);

  var refDropdownList = useRef();
  var extendedChildren = React.Children.toArray(children).filter(Boolean).map(function (child, index) {
    var valueChild = child.props.value;
    var selected = Array.isArray(value) ? value.includes(valueChild) : value === valueChild;
    return /*#__PURE__*/React.cloneElement(child, _extends({}, props, {
      index: index,
      onSelect: onSelect,
      selected: selected
    }));
  });
  var classNames = cx(BASE_CLASS, BASE_CLASS + "--" + size, (_cx = {}, _cx[CLASS_HIDDEN] = !visible, _cx));

  var getFocusedOptionIndex = function getFocusedOptionIndex(options) {
    var currentElementFocused = document.activeElement;
    return Array.from(options).reduce(function (focusedOptionIndex, option, index) {
      if (option === currentElementFocused) focusedOptionIndex = index;
      return focusedOptionIndex;
    }, 0);
  };

  var handleKeyDown = function handleKeyDown(ev) {
    var key = ev.key;
    var options = refDropdownList.current.children;
    var numOptions = options.length;
    var index = getFocusedOptionIndex(options);

    if (key === 'ArrowDown' || key === 'ArrowUp') {
      if (index >= 0 || index <= numOptions) {
        if (key === 'ArrowDown' && index < numOptions - 1) options[index + 1].focus();
        if (key === 'ArrowUp' && index > 0) options[index - 1].focus();
      }
    } else {
      var optionToFocusOn = Array.from(options).find(function (option, i) {
        return i > index && option.innerText.charAt(0).toLowerCase() === key.toLowerCase();
      }) || Array.from(options).find(function (option, i) {
        return option.innerText.charAt(0).toLowerCase() === key.toLowerCase();
      });
      optionToFocusOn && optionToFocusOn.focus();
    }

    ev.preventDefault();
    ev.stopPropagation();
  };

  if (!visible && !alwaysRender) return null;
  return /*#__PURE__*/React.createElement("ul", {
    ref: refDropdownList,
    tabIndex: 0,
    onKeyDown: handleKeyDown,
    className: classNames
  }, extendedChildren);
};

MoleculeDropdownList.displayName = 'MoleculeDropdownList';
MoleculeDropdownList.defaultProps = {
  alwaysRender: true,
  onSelect: function onSelect() {},
  size: SIZES.SMALL
};
export default MoleculeDropdownList;
export { SIZES as moleculeDropdownListSizes };

==> react-molecule-dropdown-list-1.16.0.tgz: package/lib/index.js <==
import _extends from "@babel/runtime/helpers/esm/extends";
import _objectWithoutPropertiesLoose from "@babel/runtime/helpers/esm/objectWithoutPropertiesLoose";
import { jsx as _jsx } from "react/jsx-runtime";
import { Children, cloneElement, useRef } from 'react';
import cx from 'classnames';
var BASE_CLASS = "sui-MoleculeDropdownList";
var CLASS_HIDDEN = "is-hidden";
var SIZES = {
  SMALL: 'small',
  MEDIUM: 'medium',
  LARGE: 'large'
};

var MoleculeDropdownList = function MoleculeDropdownList(_ref) {
  var _cx;

  var children = _ref.children,
      onSelect = _ref.onSelect,
      alwaysRender = _ref.alwaysRender,
      size = _ref.size,
      value = _ref.value,
      visible = _ref.visible,
      props = _objectWithoutPropertiesLoose(_ref, ["children", "onSelect", "alwaysRender", "size", "value", "visible"]);

  var refDropdownList = useRef();
  var extendedChildren = Children.toArray(children).filter(Boolean).map(function (child, index) {
    var valueChild = child.props.value;
    var selected = Array.isArray(value) ? value.includes(valueChild) : value === valueChild;
    return /*#__PURE__*/cloneElement(child, _extends({}, props, {
      index: index,
      onSelect: onSelect,
      selected: selected
    }));
  });
  var classNames = cx(BASE_CLASS, BASE_CLASS + "--" + size, (_cx = {}, _cx[CLASS_HIDDEN] = !visible, _cx));

  var getFocusedOptionIndex = function getFocusedOptionIndex(options) {
    var currentElementFocused = document.activeElement;
    return Array.from(options).reduce(function (focusedOptionIndex, option, index) {
      if (option === currentElementFocused) focusedOptionIndex = index;
      return focusedOptionIndex;
    }, 0);
  };

  var handleKeyDown = function handleKeyDown(ev) {
    var key = ev.key;
    var options = refDropdownList.current.children;
    var numOptions = options.length;
    var index = getFocusedOptionIndex(options);

    if (key === 'ArrowDown' || key === 'ArrowUp') {
      if (index >= 0 || index <= numOptions) {
        if (key === 'ArrowDown' && index < numOptions - 1) options[index + 1].focus();
        if (key === 'ArrowUp' && index > 0) options[index - 1].focus();
      }
    } else {
      var optionToFocusOn = Array.from(options).find(function (option, i) {
        return i > index && option.innerText.charAt(0).toLowerCase() === key.toLowerCase();
      }) || Array.from(options).find(function (option, i) {
        return option.innerText.charAt(0).toLowerCase() === key.toLowerCase();
      });
      optionToFocusOn && optionToFocusOn.focus();
    }

    ev.preventDefault();
    ev.stopPropagation();
  };

  if (!visible && !alwaysRender) return null;
  return /*#__PURE__*/_jsx("ul", {
    ref: refDropdownList,
    tabIndex: 0,
    onKeyDown: handleKeyDown,
    className: classNames,
    children: extendedChildren
  });
};

MoleculeDropdownList.displayName = 'MoleculeDropdownList';
MoleculeDropdownList.defaultProps = {
  alwaysRender: true,
  onSelect: function onSelect() {},
  size: SIZES.SMALL
};
export default MoleculeDropdownList;
export { SIZES as moleculeDropdownListSizes };
